#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 postgrest
version:              10.1.0
visibility:           public
id:                   postgrest-10.1.0-Cz3kXn5Dyyk5qHAIVuPJME
key:                  postgrest-10.1.0-Cz3kXn5Dyyk5qHAIVuPJME
license:              MIT
maintainer:           Steve Chavez <stevechavezast@gmail.com>
author:               Joe Nelson, Adam Baker, Steve Chavez
homepage:             https://postgrest.org
synopsis:             REST API for any Postgres database
description:
    Reads the schema of a PostgreSQL database and creates RESTful routes
    for tables, views, and functions, supporting all HTTP methods that security
    permits.

category:             Executable, PostgreSQL, Network APIs
abi:                  70221ac1ba1f1edc33a87491fc694514
exposed:              True
exposed-modules:
    PostgREST.ApiRequest PostgREST.ApiRequest.Preferences
    PostgREST.ApiRequest.QueryParams PostgREST.ApiRequest.Types
    PostgREST.App PostgREST.AppState PostgREST.Auth PostgREST.CLI
    PostgREST.Config PostgREST.Config.Database PostgREST.Config.JSPath
    PostgREST.Config.PgVersion PostgREST.Config.Proxy PostgREST.Cors
    PostgREST.Error PostgREST.Logger PostgREST.MediaType PostgREST.Plan
    PostgREST.Plan.CallPlan PostgREST.Plan.MutatePlan
    PostgREST.Plan.ReadPlan PostgREST.Query
    PostgREST.Query.QueryBuilder PostgREST.Query.SqlFragment
    PostgREST.Query.Statements PostgREST.RangeQuery PostgREST.Response
    PostgREST.Response.GucHeader PostgREST.Response.OpenAPI
    PostgREST.SchemaCache PostgREST.SchemaCache.Identifiers
    PostgREST.SchemaCache.Proc PostgREST.SchemaCache.Relationship
    PostgREST.SchemaCache.Table PostgREST.Unix PostgREST.Version
    PostgREST.Workers

hidden-modules:       Paths_postgrest
import-dirs:          /usr/lib/ghc-9.6.6/site-local/postgrest-10.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/postgrest-10.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/postgrest-10.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/postgrest
hs-libraries:         HSpostgrest-10.1.0-Cz3kXn5Dyyk5qHAIVuPJME
depends:
    HTTP-4000.4.1-K9whznG0VY9E38dui1XqaI
    Ranged-sets-0.5.0-3DDcvsfHEnB68zpwvIv1Tv
    aeson-2.2.2.0-3wIqYzgVLxh1lGuh6CHfOQ
    auto-update-0.1.6-EOieC5cOvKeKDz7xaA57nG base-4.18.2.1
    base64-bytestring-1.2.1.0-HTSPucLWQY58n8fXtuig9 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-5z8pg5dkh9iJJTZAXWxvrE
    cassava-0.5.4.1-FxFq9Bi3bC5Dg8h7id3DwD
    configurator-pg-0.2.11-FB3QcxvQxZK8A1zyrj7Gdl containers-0.6.7
    contravariant-extras-0.3.5.4-Jp1EzHgD0E5KQ707vKnuxI
    cookie-0.5.0-Dqi2dsQ09KG8Z0mbWITxu5 directory-1.3.8.5
    either-5.0.3-G1KeJdOoNhaLRG3ObwgaXW
    gitrev-1.3.1-HjgHeGOzFY1JvYhlt8eDSs
    hasql-1.6.1.1-IatRR3TMINAKb9QGggo4hQ
    hasql-dynamic-statements-0.3.1.2-1z9C4NFJy02ECQ30uhKsKG
    hasql-notifications-0.2.0.5-KEcjIuWwA1PIm3KNvLfymd
    hasql-pool-0.8.0.2-74l6FBPhbkZ6a2qkRb8CjM
    hasql-transaction-1.0.1.2-IvzRLhGst8GJUkHS5CBTk7
    heredoc-0.2.0.0-6fzsisYvDUd6tBbd4jIzIt
    http-types-0.12.4-DqlJEFWTOko3HaGBL8m7t6
    insert-ordered-containers-0.2.5.3-BkYhrFmKOyyCaqbByyQOGR
    interpolatedstring-perl6-1.0.2-1XWQ5kmoxSPBQKrB8vmOvk
    jose-0.10.0.1-CoeLSg4gixgKJSq8jfuiCv
    lens-5.3.4-GdOistvs0Ub2JwuPi3uyv5
    lens-aeson-1.2.3-1gRUzKJW8Ur1mL1WbLTUOx mtl-2.3.1
    network-3.1.4.0-DnyUe3C7n48FET4frYkCJy
    network-uri-2.6.4.2-9M7dxRCc55s4u87L8Rdwuk
    optparse-applicative-0.18.1.0-Drsi2gM4wlG4ppHqpHKUIr
    parsec-3.1.16.1 protolude-0.3.5-ABAN1451yv614hhdWpPCjK
    regex-tdfa-1.3.2.5-EMaUzDKttstEI5BfFz11ci
    retry-0.9.3.1-CoIaaRACL7024OeVHBoL3C
    scientific-0.3.8.1-9XG2AQ4sh0vL0ppOZ1hCCJ
    swagger2-2.8.10-FpRafR9CX4T9gsZQG8hE8v text-2.0.2 time-1.12.2
    unix-2.8.4.0 unordered-containers-0.2.20.1-HCJacsgu3yzJSt2gCXir1U
    vault-0.3.1.6-7o3ihykqygBImiEAtyQVOD
    vector-0.13.2.0-5aTe1V6fRGRBDLXlEcUVda
    wai-3.2.4-4rXE4pO3B1rCpC3Hr94dpe
    wai-cors-0.2.7-K6RSe2cHoX3Ic6IL1ikQ4A
    wai-extra-3.1.18-GNt5X2XdXqs5TR6xaLgpsi
    wai-logger-2.5.0-FaPcGvCQU5h2gRshYbKPIR
    warp-3.4.0-H1z1Wrsethw8cHLM85NCG

haddock-interfaces:   /usr/share/doc/postgrest/html/postgrest.haddock
haddock-html:         /usr/share/doc/postgrest/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

